@@ -76,6 +76,9 @@ class DoNotLoadError(Error):
 class InvalidTriggerNameError(Error):
 	pass
 
+class InvalidLanguagePluginError(Error):
+	pass
+	
 class DuplicateTriggerNameError(Error):
 	pass
 
@@ -90,3 +93,9 @@ class GlobalStoreObjectExistsError(Error):
 
 class GlobalStoreObjectDoesNotExistError(Error):
 	pass
+
+class BarBoxAddError(Error):
+	pass
+
+class BarBoxInvalidObjectError(Error):
+	pass
