@@ -1,34 +1,3 @@
-# -*- coding: utf-8 -*-
-# Copyright © 2005 Lateef Alabi-Oki
-#
-# This file is part of Scribes.
-#
-# Scribes is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# Scribes is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Scribes; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
-# USA
-
-"""
-This module documents a class that creates a trigger to show the text
-editor's print dialog.
-
-@author: Lateef Alabi-Oki
-@organization: The Scribes Project
-@copyright: Copyright © 2005 Lateef Alabi-Oki
-@license: GNU GPLv2 or Later
-@contact: mystilleef@gmail.com
-"""
-
 from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE
 
 class PrintTrigger(GObject):
@@ -82,7 +51,7 @@ class PrintTrigger(GObject):
 		@type self: A PrintTrigger object.
 		"""
 		# Trigger to show the print dialog.
-		self.__trigger = self.__editor.create_trigger("show_print_dialog", "ctrl - p")
+		self.__trigger = self.__editor.create_trigger("show_print_dialog", "<ctrl>p")
 		self.__editor.add_trigger(self.__trigger)
 		return
 
